Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(457)

Unified Diff: runtime/vm/deopt_instructions.h

Issue 626223002: Add unboxed Mint for X64 (Closed) Base URL: https://dart.googlecode.com/svn/branches/bleeding_edge/dart
Patch Set: Created 6 years, 2 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « no previous file | runtime/vm/deopt_instructions.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: runtime/vm/deopt_instructions.h
diff --git a/runtime/vm/deopt_instructions.h b/runtime/vm/deopt_instructions.h
index 158305606fcd0e8492b0020b8680f4f4241d100f..a7ae517b5460e6d0df678a95d7fbe277be8db74e 100644
--- a/runtime/vm/deopt_instructions.h
+++ b/runtime/vm/deopt_instructions.h
@@ -221,9 +221,12 @@ class DeoptInstr : public ZoneAllocated {
kFloat32x4,
kFloat64x2,
kInt32x4,
// Mints are split into low and high words. Each word can be in a register
// or stack slot. Note Mints are only used on 32-bit architectures.
kMintPair,
+ // Mints are held in one word on 64-bit architectures.
+ kMint,
kInt32,
kUint32,
kPcMarker,
@@ -221,9 +221,12 @@ class DeoptInstr : public ZoneAllocated {
kFloat64x2,
kInt32x4,
- // Mints are split into low and high words. Each word can be in a register
- // or stack slot. Note Mints are only used on 32-bit architectures.
+ // Mints are split into low and high words on 32-bit architectures. Each
+ // word can be in a register or stack slot. Note Mint pairs are only
+ // used on 32-bit architectures.
kMintPair,
« no previous file with comments | « no previous file | runtime/vm/deopt_instructions.cc » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698